====================================
JetStream QueryService
====================================

JSA QueryService is a python package built
for handling generic CRUD (Create, Read,
Update, Delete) services, for availability
across all of JetStream's micro-services.

